<a id="mypy-boto3-greengrass"></a>

# mypy-boto3-greengrass

[![PyPI - mypy-boto3-greengrass](https://img.shields.io/pypi/v/mypy-boto3-greengrass.svg?color=blue)](https://pypi.org/project/mypy-boto3-greengrass)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-greengrass.svg?color=blue)](https://pypi.org/project/mypy-boto3-greengrass)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-greengrass?color=blue)](https://pypistats.org/packages/mypy-boto3-greengrass)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.Greengrass 1.17.110](https://boto3.amazonaws.com/v1/documentation/api/1.17.110/reference/services/greengrass.html#Greengrass)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.22.1](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-greengrass docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_greengrass/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-greengrass](#mypy-boto3-greengrass)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `Greengrass` service.

```bash
python -m pip install boto3-stubs[greengrass]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[greengrass]` in your environment:
  `python -m pip install 'boto3-stubs[greengrass]'`

Both type checking and auto-complete should work for `Greengrass` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[greengrass]` in your environment:
  `python -m pip install 'boto3-stubs[greengrass]'`

Both type checking and auto-complete should work for `Greengrass` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[greengrass]` in your environment:
  `python -m pip install 'boto3-stubs[greengrass]'`
- Run `mypy` as usual

Type checking should work for `Greengrass` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[greengrass]` in your environment:
  `python -m pip install 'boto3-stubs[greengrass]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Greengrass` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`GreengrassClient` provides annotations for `boto3.client("greengrass")`.

```python
import boto3

from mypy_boto3_greengrass import GreengrassClient

client: GreengrassClient = boto3.client("greengrass")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: GreengrassClient = session.client("greengrass")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_greengrass.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_greengrass import GreengrassClient
from mypy_boto3_greengrass.paginator import (
    ListBulkDeploymentDetailedReportsPaginator,
    ListBulkDeploymentsPaginator,
    ListConnectorDefinitionVersionsPaginator,
    ListConnectorDefinitionsPaginator,
    ListCoreDefinitionVersionsPaginator,
    ListCoreDefinitionsPaginator,
    ListDeploymentsPaginator,
    ListDeviceDefinitionVersionsPaginator,
    ListDeviceDefinitionsPaginator,
    ListFunctionDefinitionVersionsPaginator,
    ListFunctionDefinitionsPaginator,
    ListGroupVersionsPaginator,
    ListGroupsPaginator,
    ListLoggerDefinitionVersionsPaginator,
    ListLoggerDefinitionsPaginator,
    ListResourceDefinitionVersionsPaginator,
    ListResourceDefinitionsPaginator,
    ListSubscriptionDefinitionVersionsPaginator,
    ListSubscriptionDefinitionsPaginator,
)

client: GreengrassClient = boto3.client("greengrass")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_bulk_deployment_detailed_reports_paginator: ListBulkDeploymentDetailedReportsPaginator = client.get_paginator("list_bulk_deployment_detailed_reports")
list_bulk_deployments_paginator: ListBulkDeploymentsPaginator = client.get_paginator("list_bulk_deployments")
list_connector_definition_versions_paginator: ListConnectorDefinitionVersionsPaginator = client.get_paginator("list_connector_definition_versions")
list_connector_definitions_paginator: ListConnectorDefinitionsPaginator = client.get_paginator("list_connector_definitions")
list_core_definition_versions_paginator: ListCoreDefinitionVersionsPaginator = client.get_paginator("list_core_definition_versions")
list_core_definitions_paginator: ListCoreDefinitionsPaginator = client.get_paginator("list_core_definitions")
list_deployments_paginator: ListDeploymentsPaginator = client.get_paginator("list_deployments")
list_device_definition_versions_paginator: ListDeviceDefinitionVersionsPaginator = client.get_paginator("list_device_definition_versions")
list_device_definitions_paginator: ListDeviceDefinitionsPaginator = client.get_paginator("list_device_definitions")
list_function_definition_versions_paginator: ListFunctionDefinitionVersionsPaginator = client.get_paginator("list_function_definition_versions")
list_function_definitions_paginator: ListFunctionDefinitionsPaginator = client.get_paginator("list_function_definitions")
list_group_versions_paginator: ListGroupVersionsPaginator = client.get_paginator("list_group_versions")
list_groups_paginator: ListGroupsPaginator = client.get_paginator("list_groups")
list_logger_definition_versions_paginator: ListLoggerDefinitionVersionsPaginator = client.get_paginator("list_logger_definition_versions")
list_logger_definitions_paginator: ListLoggerDefinitionsPaginator = client.get_paginator("list_logger_definitions")
list_resource_definition_versions_paginator: ListResourceDefinitionVersionsPaginator = client.get_paginator("list_resource_definition_versions")
list_resource_definitions_paginator: ListResourceDefinitionsPaginator = client.get_paginator("list_resource_definitions")
list_subscription_definition_versions_paginator: ListSubscriptionDefinitionVersionsPaginator = client.get_paginator("list_subscription_definition_versions")
list_subscription_definitions_paginator: ListSubscriptionDefinitionsPaginator = client.get_paginator("list_subscription_definitions")
```

<a id="literals"></a>

### Literals

`mypy_boto3_greengrass.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_greengrass.literals import (
    BulkDeploymentStatusType,
    ConfigurationSyncStatusType,
    DeploymentTypeType,
    EncodingTypeType,
    FunctionIsolationModeType,
    ListBulkDeploymentDetailedReportsPaginatorName,
    ListBulkDeploymentsPaginatorName,
    ListConnectorDefinitionVersionsPaginatorName,
    ListConnectorDefinitionsPaginatorName,
    ListCoreDefinitionVersionsPaginatorName,
    ListCoreDefinitionsPaginatorName,
    ListDeploymentsPaginatorName,
    ListDeviceDefinitionVersionsPaginatorName,
    ListDeviceDefinitionsPaginatorName,
    ListFunctionDefinitionVersionsPaginatorName,
    ListFunctionDefinitionsPaginatorName,
    ListGroupVersionsPaginatorName,
    ListGroupsPaginatorName,
    ListLoggerDefinitionVersionsPaginatorName,
    ListLoggerDefinitionsPaginatorName,
    ListResourceDefinitionVersionsPaginatorName,
    ListResourceDefinitionsPaginatorName,
    ListSubscriptionDefinitionVersionsPaginatorName,
    ListSubscriptionDefinitionsPaginatorName,
    LoggerComponentType,
    LoggerLevelType,
    LoggerTypeType,
    PermissionType,
    SoftwareToUpdateType,
    TelemetryType,
    UpdateAgentLogLevelType,
    UpdateTargetsArchitectureType,
    UpdateTargetsOperatingSystemType,
)

def check_value(value: BulkDeploymentStatusType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_greengrass.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_greengrass.type_defs import (
    AssociateRoleToGroupRequestRequestTypeDef,
    AssociateRoleToGroupResponseTypeDef,
    AssociateServiceRoleToAccountRequestRequestTypeDef,
    AssociateServiceRoleToAccountResponseTypeDef,
    BulkDeploymentMetricsTypeDef,
    BulkDeploymentResultTypeDef,
    BulkDeploymentTypeDef,
    ConnectivityInfoTypeDef,
    ConnectorDefinitionVersionTypeDef,
    ConnectorTypeDef,
    CoreDefinitionVersionTypeDef,
    CoreTypeDef,
    CreateConnectorDefinitionRequestRequestTypeDef,
    CreateConnectorDefinitionResponseTypeDef,
    CreateConnectorDefinitionVersionRequestRequestTypeDef,
    CreateConnectorDefinitionVersionResponseTypeDef,
    CreateCoreDefinitionRequestRequestTypeDef,
    CreateCoreDefinitionResponseTypeDef,
    CreateCoreDefinitionVersionRequestRequestTypeDef,
    CreateCoreDefinitionVersionResponseTypeDef,
    CreateDeploymentRequestRequestTypeDef,
    CreateDeploymentResponseTypeDef,
    CreateDeviceDefinitionRequestRequestTypeDef,
    CreateDeviceDefinitionResponseTypeDef,
    CreateDeviceDefinitionVersionRequestRequestTypeDef,
    CreateDeviceDefinitionVersionResponseTypeDef,
    CreateFunctionDefinitionRequestRequestTypeDef,
    CreateFunctionDefinitionResponseTypeDef,
    CreateFunctionDefinitionVersionRequestRequestTypeDef,
    CreateFunctionDefinitionVersionResponseTypeDef,
    CreateGroupCertificateAuthorityRequestRequestTypeDef,
    CreateGroupCertificateAuthorityResponseTypeDef,
    CreateGroupRequestRequestTypeDef,
    CreateGroupResponseTypeDef,
    CreateGroupVersionRequestRequestTypeDef,
    CreateGroupVersionResponseTypeDef,
    CreateLoggerDefinitionRequestRequestTypeDef,
    CreateLoggerDefinitionResponseTypeDef,
    CreateLoggerDefinitionVersionRequestRequestTypeDef,
    CreateLoggerDefinitionVersionResponseTypeDef,
    CreateResourceDefinitionRequestRequestTypeDef,
    CreateResourceDefinitionResponseTypeDef,
    CreateResourceDefinitionVersionRequestRequestTypeDef,
    CreateResourceDefinitionVersionResponseTypeDef,
    CreateSoftwareUpdateJobRequestRequestTypeDef,
    CreateSoftwareUpdateJobResponseTypeDef,
    CreateSubscriptionDefinitionRequestRequestTypeDef,
    CreateSubscriptionDefinitionResponseTypeDef,
    CreateSubscriptionDefinitionVersionRequestRequestTypeDef,
    CreateSubscriptionDefinitionVersionResponseTypeDef,
    DefinitionInformationTypeDef,
    DeleteConnectorDefinitionRequestRequestTypeDef,
    DeleteCoreDefinitionRequestRequestTypeDef,
    DeleteDeviceDefinitionRequestRequestTypeDef,
    DeleteFunctionDefinitionRequestRequestTypeDef,
    DeleteGroupRequestRequestTypeDef,
    DeleteLoggerDefinitionRequestRequestTypeDef,
    DeleteResourceDefinitionRequestRequestTypeDef,
    DeleteSubscriptionDefinitionRequestRequestTypeDef,
    DeploymentTypeDef,
    DeviceDefinitionVersionTypeDef,
    DeviceTypeDef,
    DisassociateRoleFromGroupRequestRequestTypeDef,
    DisassociateRoleFromGroupResponseTypeDef,
    DisassociateServiceRoleFromAccountResponseTypeDef,
    ErrorDetailTypeDef,
    FunctionConfigurationEnvironmentTypeDef,
    FunctionConfigurationTypeDef,
    FunctionDefaultConfigTypeDef,
    FunctionDefaultExecutionConfigTypeDef,
    FunctionDefinitionVersionTypeDef,
    FunctionExecutionConfigTypeDef,
    FunctionRunAsConfigTypeDef,
    FunctionTypeDef,
    GetAssociatedRoleRequestRequestTypeDef,
    GetAssociatedRoleResponseTypeDef,
    GetBulkDeploymentStatusRequestRequestTypeDef,
    GetBulkDeploymentStatusResponseTypeDef,
    GetConnectivityInfoRequestRequestTypeDef,
    GetConnectivityInfoResponseTypeDef,
    GetConnectorDefinitionRequestRequestTypeDef,
    GetConnectorDefinitionResponseTypeDef,
    GetConnectorDefinitionVersionRequestRequestTypeDef,
    GetConnectorDefinitionVersionResponseTypeDef,
    GetCoreDefinitionRequestRequestTypeDef,
    GetCoreDefinitionResponseTypeDef,
    GetCoreDefinitionVersionRequestRequestTypeDef,
    GetCoreDefinitionVersionResponseTypeDef,
    GetDeploymentStatusRequestRequestTypeDef,
    GetDeploymentStatusResponseTypeDef,
    GetDeviceDefinitionRequestRequestTypeDef,
    GetDeviceDefinitionResponseTypeDef,
    GetDeviceDefinitionVersionRequestRequestTypeDef,
    GetDeviceDefinitionVersionResponseTypeDef,
    GetFunctionDefinitionRequestRequestTypeDef,
    GetFunctionDefinitionResponseTypeDef,
    GetFunctionDefinitionVersionRequestRequestTypeDef,
    GetFunctionDefinitionVersionResponseTypeDef,
    GetGroupCertificateAuthorityRequestRequestTypeDef,
    GetGroupCertificateAuthorityResponseTypeDef,
    GetGroupCertificateConfigurationRequestRequestTypeDef,
    GetGroupCertificateConfigurationResponseTypeDef,
    GetGroupRequestRequestTypeDef,
    GetGroupResponseTypeDef,
    GetGroupVersionRequestRequestTypeDef,
    GetGroupVersionResponseTypeDef,
    GetLoggerDefinitionRequestRequestTypeDef,
    GetLoggerDefinitionResponseTypeDef,
    GetLoggerDefinitionVersionRequestRequestTypeDef,
    GetLoggerDefinitionVersionResponseTypeDef,
    GetResourceDefinitionRequestRequestTypeDef,
    GetResourceDefinitionResponseTypeDef,
    GetResourceDefinitionVersionRequestRequestTypeDef,
    GetResourceDefinitionVersionResponseTypeDef,
    GetServiceRoleForAccountResponseTypeDef,
    GetSubscriptionDefinitionRequestRequestTypeDef,
    GetSubscriptionDefinitionResponseTypeDef,
    GetSubscriptionDefinitionVersionRequestRequestTypeDef,
    GetSubscriptionDefinitionVersionResponseTypeDef,
    GetThingRuntimeConfigurationRequestRequestTypeDef,
    GetThingRuntimeConfigurationResponseTypeDef,
    GroupCertificateAuthorityPropertiesTypeDef,
    GroupInformationTypeDef,
    GroupOwnerSettingTypeDef,
    GroupVersionTypeDef,
    ListBulkDeploymentDetailedReportsRequestRequestTypeDef,
    ListBulkDeploymentDetailedReportsResponseTypeDef,
    ListBulkDeploymentsRequestRequestTypeDef,
    ListBulkDeploymentsResponseTypeDef,
    ListConnectorDefinitionVersionsRequestRequestTypeDef,
    ListConnectorDefinitionVersionsResponseTypeDef,
    ListConnectorDefinitionsRequestRequestTypeDef,
    ListConnectorDefinitionsResponseTypeDef,
    ListCoreDefinitionVersionsRequestRequestTypeDef,
    ListCoreDefinitionVersionsResponseTypeDef,
    ListCoreDefinitionsRequestRequestTypeDef,
    ListCoreDefinitionsResponseTypeDef,
    ListDeploymentsRequestRequestTypeDef,
    ListDeploymentsResponseTypeDef,
    ListDeviceDefinitionVersionsRequestRequestTypeDef,
    ListDeviceDefinitionVersionsResponseTypeDef,
    ListDeviceDefinitionsRequestRequestTypeDef,
    ListDeviceDefinitionsResponseTypeDef,
    ListFunctionDefinitionVersionsRequestRequestTypeDef,
    ListFunctionDefinitionVersionsResponseTypeDef,
    ListFunctionDefinitionsRequestRequestTypeDef,
    ListFunctionDefinitionsResponseTypeDef,
    ListGroupCertificateAuthoritiesRequestRequestTypeDef,
    ListGroupCertificateAuthoritiesResponseTypeDef,
    ListGroupVersionsRequestRequestTypeDef,
    ListGroupVersionsResponseTypeDef,
    ListGroupsRequestRequestTypeDef,
    ListGroupsResponseTypeDef,
    ListLoggerDefinitionVersionsRequestRequestTypeDef,
    ListLoggerDefinitionVersionsResponseTypeDef,
    ListLoggerDefinitionsRequestRequestTypeDef,
    ListLoggerDefinitionsResponseTypeDef,
    ListResourceDefinitionVersionsRequestRequestTypeDef,
    ListResourceDefinitionVersionsResponseTypeDef,
    ListResourceDefinitionsRequestRequestTypeDef,
    ListResourceDefinitionsResponseTypeDef,
    ListSubscriptionDefinitionVersionsRequestRequestTypeDef,
    ListSubscriptionDefinitionVersionsResponseTypeDef,
    ListSubscriptionDefinitionsRequestRequestTypeDef,
    ListSubscriptionDefinitionsResponseTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    LocalDeviceResourceDataTypeDef,
    LocalVolumeResourceDataTypeDef,
    LoggerDefinitionVersionTypeDef,
    LoggerTypeDef,
    PaginatorConfigTypeDef,
    ResetDeploymentsRequestRequestTypeDef,
    ResetDeploymentsResponseTypeDef,
    ResourceAccessPolicyTypeDef,
    ResourceDataContainerTypeDef,
    ResourceDefinitionVersionTypeDef,
    ResourceDownloadOwnerSettingTypeDef,
    ResourceTypeDef,
    ResponseMetadataTypeDef,
    RuntimeConfigurationTypeDef,
    S3MachineLearningModelResourceDataTypeDef,
    SageMakerMachineLearningModelResourceDataTypeDef,
    SecretsManagerSecretResourceDataTypeDef,
    StartBulkDeploymentRequestRequestTypeDef,
    StartBulkDeploymentResponseTypeDef,
    StopBulkDeploymentRequestRequestTypeDef,
    SubscriptionDefinitionVersionTypeDef,
    SubscriptionTypeDef,
    TagResourceRequestRequestTypeDef,
    TelemetryConfigurationTypeDef,
    TelemetryConfigurationUpdateTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateConnectivityInfoRequestRequestTypeDef,
    UpdateConnectivityInfoResponseTypeDef,
    UpdateConnectorDefinitionRequestRequestTypeDef,
    UpdateCoreDefinitionRequestRequestTypeDef,
    UpdateDeviceDefinitionRequestRequestTypeDef,
    UpdateFunctionDefinitionRequestRequestTypeDef,
    UpdateGroupCertificateConfigurationRequestRequestTypeDef,
    UpdateGroupCertificateConfigurationResponseTypeDef,
    UpdateGroupRequestRequestTypeDef,
    UpdateLoggerDefinitionRequestRequestTypeDef,
    UpdateResourceDefinitionRequestRequestTypeDef,
    UpdateSubscriptionDefinitionRequestRequestTypeDef,
    UpdateThingRuntimeConfigurationRequestRequestTypeDef,
    VersionInformationTypeDef,
)

def get_structure() -> AssociateRoleToGroupRequestRequestTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-greengrass` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-greengrass docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_greengrass/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
